@@ -677,7 +677,7 @@ App <- R6::R6Class(
                            description = NULL,
                            execution_settings = NULL,
                            inputs = NULL,
-                           output_location = output_location,
+                           output_location = NULL,
                            batch = NULL,
                            batch_input = NULL,
                            batch_by = NULL,
