@@ -260,12 +260,10 @@ Volumes <- R6::R6Class(
 
       path <- glue::glue(self$URL[["create"]])
 
-      res <- sevenbridges2::api(
+      res <- self$auth$api(
         path = path,
         method = "POST",
         body = body,
-        token = self$auth$get_token(),
-        base_url = self$auth$url,
         advance_access = TRUE
       )
 
@@ -406,12 +404,10 @@ Volumes <- R6::R6Class(
 
       path <- glue::glue(self$URL[["create"]])
 
-      res <- sevenbridges2::api(
+      res <- self$auth$api(
         path = path,
         method = "POST",
         body = body,
-        token = self$auth$get_token(),
-        base_url = self$auth$url,
         advance_access = TRUE
       )
 
@@ -533,12 +529,10 @@ Volumes <- R6::R6Class(
 
       path <- glue::glue(self$URL[["create"]])
 
-      res <- sevenbridges2::api(
+      res <- self$auth$api(
         path = path,
         method = "POST",
         body = body,
-        token = self$auth$get_token(),
-        base_url = self$auth$url,
         advance_access = TRUE
       )
 
@@ -649,7 +643,7 @@ Volumes <- R6::R6Class(
           configuration <- transform_configuration_param(config_params)
           args[["credentials"]][["configuration"]] <- configuration
         } else {
-          rlang::abort("Configuration parameter within credentials is mandatory. \n Please, provide a path to JSON configuration file or a named list containing all configuration values.") # nolint
+          rlang::abort("Configuration parameter within credentials is mandatory. \n Please provide a path to JSON configuration file or a named list containing all configuration values.") # nolint
         }
       }
 
@@ -676,12 +670,10 @@ Volumes <- R6::R6Class(
 
       path <- glue::glue(self$URL[["create"]])
 
-      res <- sevenbridges2::api(
+      res <- self$auth$api(
         path = path,
         method = "POST",
         body = body,
-        token = self$auth$get_token(),
-        base_url = self$auth$url,
         advance_access = TRUE
       )
 
@@ -809,12 +801,10 @@ Volumes <- R6::R6Class(
 
       path <- glue::glue(self$URL[["create"]])
 
-      res <- sevenbridges2::api(
+      res <- self$auth$api(
         path = path,
         method = "POST",
         body = body,
-        token = self$auth$get_token(),
-        base_url = self$auth$url,
         advance_access = TRUE
       )
 
@@ -922,12 +912,10 @@ Volumes <- R6::R6Class(
 
       path <- glue::glue(self$URL[["create"]])
 
-      res <- sevenbridges2::api(
+      res <- self$auth$api(
         path = path,
         method = "POST",
         body = body,
-        token = self$auth$get_token(),
-        base_url = self$auth$url,
         advance_access = TRUE
       )
 
