@@ -149,7 +149,7 @@ test_that("check_folder_name function throws error when expected", {
 
   testthat::expect_error(
     do.call(check_folder_name, missing_name),
-    regexp = "Please, provide the folder's name.",
+    regexp = "Please provide the folder's name.",
     fixed = TRUE
   )
   testthat::expect_error(
@@ -441,21 +441,21 @@ test_that("transform_configuration_param throws error when needed", {
   # Provide configuration as NULL
   testthat::expect_error(
     transform_configuration_param(configuration = NULL),
-    regexp = "Invalid configuration parameter! \n Please, provide a string path to the JSON file or a named list.", # nolint
+    regexp = "Invalid configuration parameter! \n Please provide a string path to the JSON file or a named list.", # nolint
     fixed = TRUE
   )
 
   # Provide configuration as empty list
   testthat::expect_error(
     transform_configuration_param(configuration = list()),
-    regexp = "Invalid configuration parameter! \n Please, provide a string path to the JSON file or a named list.", # nolint
+    regexp = "Invalid configuration parameter! \n Please provide a string path to the JSON file or a named list.", # nolint
     fixed = TRUE
   )
 
   # Provide configuration as unnamed list
   testthat::expect_error(
     transform_configuration_param(configuration = list("unnamed list")),
-    regexp = "Invalid configuration parameter! \n Please, provide a string path to the JSON file or a named list.", # nolint
+    regexp = "Invalid configuration parameter! \n Please provide a string path to the JSON file or a named list.", # nolint
     fixed = TRUE
   )
 
@@ -535,7 +535,7 @@ test_that("check_upload_params throws error when needed", {
   # Fails when part length is too big
   testthat::expect_error(
     do.call(check_upload_params, test_bad_part_length),
-    regexp = "Total number of parts must be from 1 to 10,000 (inclusive). Please, modify part_size.", # nolint
+    regexp = "Total number of parts must be from 1 to 10,000 (inclusive). Please modify part_size.", # nolint
     fixed = TRUE
   )
 })
@@ -559,3 +559,122 @@ test_that("check_and_transform_datetime works as expected", {
     expected = "2016-04-01 14:25:50"
   )
 })
+
+# nolint start
+test_that("check_and_process_file_details throws error for invalid name type", {
+  file_with_wrong_name <- list2env(as.list(setup_file_obj), envir = new.env())
+  file_with_wrong_name$name <- 123
+
+  testthat::expect_error(
+    check_and_process_file_details(file_with_wrong_name),
+    regexp = "Assertion on 'file$name' failed: Must be of type 'string', not 'double'.",
+    fixed = TRUE
+  )
+})
+
+test_that("check_and_process_file_details throws error for invalid tags type", {
+  file_with_invalid_tags <- list2env(as.list(setup_file_obj), envir = new.env())
+  file_with_invalid_tags$tags <- "test-tag"
+
+  testthat::expect_error(
+    check_and_process_file_details(file_with_invalid_tags),
+    regexp = "Assertion on 'file$tags' failed: Must be of type 'list', not 'character'.",
+    fixed = TRUE
+  )
+})
+
+test_that("check_and_process_file_details throws error for invalid metadata type", {
+  file_with_invalid_metadata <- list2env(as.list(setup_file_obj), envir = new.env())
+  file_with_invalid_metadata$metadata <- c("sample_id", "acdc")
+
+  testthat::expect_error(
+    check_and_process_file_details(file_with_invalid_metadata),
+    regexp = "Assertion on 'file$metadata' failed: Must be of type 'list', not 'character'.",
+    fixed = TRUE
+  )
+})
+
+test_that("check_and_process_file_details works as expected", {
+  # Call the function with a valid File object
+  result <- check_and_process_file_details(setup_file_obj)
+
+  # Create the expected result list
+  expected_result <- list(
+    id = "file-id",
+    name = "File name",
+    tags = list("tag_1"),
+    metadata = list(
+      sbg_public_files_category = "test",
+      reference_genome = "HG19_Broad_variant",
+      sample_id = "HCC1143_1M",
+      case_id = "CCLE-HCC1143",
+      investigation = "CCLE-BRCA"
+    )
+  )
+
+  # Check that the result is a list
+  testthat::expect_type(result, "list")
+
+  # Check that the result matches the expected result
+  testthat::expect_equal(result, expected_result)
+})
+# nolint end
+
+test_that("check_response_and_notify_user throws an error when expected", {
+  test_valid_files_param <- list("file_id_1", "file_id_2", "file_id_3")
+  test_valid_res_param <- list(items = list(
+    list(error = list(status = 404, code = 5002, message = "Requested file does not exist.")), # nolint
+    list(resource = list(id = "file_id_2")),
+    list(error = list(status = 404, code = 5002, message = "Requested file does not exist.")) # nolint
+  ))
+
+  # Fails when no files are provided
+  testthat::expect_error(check_response_and_notify_user(res = test_valid_res_param), # nolint
+    regexp = "Files parameter is required.",
+    fixed = TRUE
+  )
+
+  # Fails when res parameter is not provided
+  testthat::expect_error(check_response_and_notify_user(files = test_valid_files_param), # nolint
+    regexp = "Res parameter is required.",
+    fixed = TRUE
+  )
+
+  # Fails when bad files parameter is provided (list of numeric values)
+  test_bad_files_param_1 <- list(1, 2, 3)
+  testthat::expect_error(
+    check_response_and_notify_user(files = test_bad_files_param_1, res = test_valid_res_param), # nolint
+    regexp = "Assertion on 'files' failed: May only contain the following types: {character}, but element 1 has type 'numeric'.", # nolint
+    fixed = TRUE
+  )
+
+  # Fails when bad files parameter is provided (vector of strings)
+  test_bad_files_param_2 <- c("file_1_id", "file_2_id", "file_3_id")
+  testthat::expect_error(
+    check_response_and_notify_user(files = test_bad_files_param_2, res = test_valid_res_param), # nolint
+    regexp = "Assertion on 'files' failed: Must be of type 'list', not 'character'.", # nolint
+    fixed = TRUE
+  )
+
+  # Fails when bad res parameter is provided
+  test_bad_res_param <- 42
+  testthat::expect_error(
+    check_response_and_notify_user(files = test_valid_files_param, res = test_bad_res_param), # nolint
+    regexp = "Assertion on 'res' failed: Must be of type 'list', not 'double'.", # nolint
+    fixed = TRUE
+  )
+})
+
+test_that("check_response_and_notify_user works as expected", {
+  files <- list("file_id_1", "file_id_2", "file_id_3")
+  res <- list(items = list(
+    list(error = list(status = 404, code = 5002, message = "Requested file does not exist.")), # nolint
+    list(resource = list(id = "file_id_2")),
+    list(error = list(status = 404, code = 5002, message = "Requested file does not exist.")) # nolint
+  ))
+
+  # Generates the expected console output
+  testthat::skip_on_ci()
+  testthat::skip_on_cran()
+  testthat::expect_snapshot(check_response_and_notify_user(files, res))
+})
